@@ -15,10 +15,12 @@ APP_HOME_ASSISTANT = "B12CE3CA"
 APP_SUPLA = "A41B766D"
 APP_YLEAREENA = "A9BCCB7C"
 APP_BUBBLEUPNP = "3927FA74"
+APP_BBCSOUNDS = "03977A48"
+APP_BBCIPLAYER = "5E81F6DB"
 
 
 def get_possible_app_ids():
-    """ Returns all possible app ids. """
+    """Returns all possible app ids."""
 
     try:
         req = requests.get(
@@ -34,7 +36,7 @@ def get_possible_app_ids():
 
 
 def get_app_config(app_id):
-    """ Get specific configuration for 'app_id'. """
+    """Get specific configuration for 'app_id'."""
     try:
         req = requests.get(
             ("https://clients3.google.com/cast/chromecast/device/app?a={}").format(
