@@ -8,7 +8,7 @@ from ..error import UnsupportedNamespace, ControllerNotRegistered
 
 
 class BaseController(abc.ABC):
-    """ ABC for namespace controllers. """
+    """ABC for namespace controllers."""
 
     def __init__(self, namespace, supporting_app_id=None, target_platform=False):
         """
@@ -38,16 +38,18 @@ class BaseController(abc.ABC):
             and self.namespace in self._socket_client.app_namespaces
         )
 
-    def launch(self, callback_function=None):
-        """ If set, launches app related to the controller. """
+    def launch(self, callback_function=None, force_launch=False):
+        """If set, launches app related to the controller."""
         self._check_registered()
 
         self._socket_client.receiver_controller.launch_app(
-            self.supporting_app_id, callback_function=callback_function
+            self.supporting_app_id,
+            force_launch=force_launch,
+            callback_function=callback_function,
         )
 
     def registered(self, socket_client):
-        """ Called when a controller is registered. """
+        """Called when a controller is registered."""
         self._socket_client = socket_client
 
         if self.target_platform:
@@ -60,7 +62,7 @@ class BaseController(abc.ABC):
         namespace of this controller."""
 
     def channel_disconnected(self):
-        """ Called when a channel is disconnected. """
+        """Called when a channel is disconnected."""
 
     def send_message(self, data, inc_session_id=False, callback_function=None):
         """
@@ -103,12 +105,12 @@ class BaseController(abc.ABC):
         return False
 
     def tear_down(self):
-        """ Called when we are shutting down. """
+        """Called when we are shutting down."""
         self._socket_client = None
         self._message_func = None
 
     def _check_registered(self):
-        """ Helper method to see if we are registered with a Cast object. """
+        """Helper method to see if we are registered with a Cast object."""
         if self._socket_client is None:
             raise ControllerNotRegistered(
                 (
