@@ -120,7 +120,7 @@ class ZeroConfListener:
         self._add_update_service(zconf, typ, name, self._cast_listener.add_cast)
 
     def _add_update_service(self, zconf, typ, name, callback):
-        """ Add or update a service. """
+        """Add or update a service."""
         service = None
         tries = 0
         if name.endswith("_sub._googlecast._tcp.local."):
@@ -207,7 +207,7 @@ HOSTLISTENER_MAX_FAIL = 5
 
 
 class HostBrowser(threading.Thread):
-    """"Repeateadly poll a set of known hosts."""
+    """Repeateadly poll a set of known hosts."""
 
     def __init__(self, cast_listener, devices, lock):
         super().__init__(daemon=True)
@@ -496,7 +496,7 @@ def stop_discovery(cast_browser):
 
 
 def discover_chromecasts(
-    max_devices=None, timeout=DISCOVER_TIMEOUT, zeroconf_instance=None
+    max_devices=None, timeout=DISCOVER_TIMEOUT, zeroconf_instance=None, known_hosts=None
 ):
     """
     Discover chromecasts on the network.
@@ -517,13 +517,13 @@ def discover_chromecasts(
 
     discover_complete = threading.Event()
     zconf = zeroconf_instance or zeroconf.Zeroconf()
-    browser = CastBrowser(SimpleCastListener(add_callback), zconf)
+    browser = CastBrowser(SimpleCastListener(add_callback), zconf, known_hosts)
     browser.start_discovery()
 
     # Wait for the timeout or the maximum number of devices
     discover_complete.wait(timeout)
 
-    return (browser.devices.values(), browser)
+    return (list(browser.devices.values()), browser)
 
 
 def discover_listed_chromecasts(
@@ -531,6 +531,7 @@ def discover_listed_chromecasts(
     uuids=None,
     discovery_timeout=DISCOVER_TIMEOUT,
     zeroconf_instance=None,
+    known_hosts=None,
 ):
     """
     Searches the network for chromecast devices matching a list of friendly
@@ -567,9 +568,9 @@ def discover_listed_chromecasts(
     discover_complete = threading.Event()
 
     zconf = zeroconf_instance or zeroconf.Zeroconf()
-    browser = CastBrowser(SimpleCastListener(add_callback), zconf)
+    browser = CastBrowser(SimpleCastListener(add_callback), zconf, known_hosts)
     browser.start_discovery()
 
     # Wait for the timeout or found all wanted devices
     discover_complete.wait(discovery_timeout)
-    return (cc_list.values(), browser)
+    return (list(cc_list.values()), browser)
